use clap::{Parser};
use std::{thread, time};

use gargantext_notifications::notifications::connection::{ce_test_push};


#[derive(Parser, Debug)]
#[command(version, about, long_about = None)]
struct Args {
    /// Number of pings to send
    #[arg(long, default_value_t = 1)]
    num_pings: u32,

    /// Delay between pings (ms)
    #[arg(long, default_value_t = 100)]
    ping_delay: u64,

    /// Number of threads
    #[arg(long, default_value_t = 1)]
    num_threads: u8,
}


fn main() {
    let args = Args::parse();

    let sleep_duration = time::Duration::from_millis(args.ping_delay);

    let mut handles = Vec::new();

    for _ in 0..args.num_threads {
	let h = thread::spawn(move || {
	    worker(args.num_pings, sleep_duration);
	});
	handles.push(h);
    }
    for h in handles {
	h.join().unwrap();
    }
    // handles.iter().for_each(|h| h.join().unwrap());
}

fn worker(num_pings: u32, sleep_duration: time::Duration) {
    for _ in 0..num_pings {
	let _ = ce_test_push().unwrap();
	thread::sleep(sleep_duration);
    }    
}
