{
  description = "Gargantext notifications CLI app";

  inputs = {
    systems.url = "github:nix-systems/x86_64-linux";
    #nixpkgs2311.url = "github:nixos/nixpkgs?ref=23.11";
    #nixpkgs.url = "github:nixos/nixpkgs?rev=9603f963f5014cff024b519445f3381113642be2";
    rust-overlay.url = "github:oxalica/rust-overlay";
    flake-utils.follows = "rust-overlay/flake-utils";
    # https://www.nixhub.io/packages/duckdb
    nixpkgs.url = "nixpkgs/cf8cc1201be8bc71b7cbbbdaf349b22f4f99c7ae";
    naersk.url = "github:nix-community/naersk";
  };

  outputs = { self, nixpkgs, flake-utils, rust-overlay, systems, naersk }@inputs:
    flake-utils.lib.eachDefaultSystem (system:
      let
        overlays = [ (import rust-overlay)
                   ];
        pkgs = import nixpkgs {
          inherit system overlays;
        };

        naersk' = pkgs.callPackage naersk {};

        buildInputs = with pkgs; [
          openssl
          pkg-config
          eza
          rust-bin.stable.latest.default
          #rust-bin.selectLatestNightlyWith (toolchain: toolchain.default)
          curl
          nanomsg
          zip
          
          poke
          stdenv.cc.libc
        ];

        # https://discourse.nixos.org/t/get-clangd-to-find-standard-headers-in-nix-shell/11268/4
         nativeBuildInputs = with pkgs; [
           llvmPackages_16.clang
           llvmPackages_16.libclang
         ];
      in
        with pkgs;
        rec {
          devShells.default = mkShell {
            inherit buildInputs nativeBuildInputs;
            
            shellHook = ''
            alias ls=eza
            alias find=fd
            export LIBCLANG_PATH="${llvmPackages.libclang.lib}/lib";
          '';     
          };

          defaultPackage = naersk'.buildPackage {
            src = ./.;
            inherit buildInputs nativeBuildInputs;
            # Needed so bindgen can find libclang.so
            LIBCLANG_PATH = lib.makeLibraryPath [ llvmPackages.libclang.lib ];
          };
        }
    );
}
